@@ -34,12 +34,10 @@
 #include "ephy-bookmarks-import.h"
 #include "ephy-bookmark-properties.h"
 #include "ephy-prefs.h"
+#include "ephy-settings.h"
 #include "ephy-marshal.h"
 #include "ephy-signal-accumulator.h"
 #include "ephy-stock-icons.h"
-#include "ephy-glib-compat.h"
-
-#include "eel-gconf-extensions.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
@@ -83,7 +81,6 @@ struct _EphyBookmarksPrivate
 	EphyNode *smartbookmarks;
 	EphyNode *lower_fav;
 	double lower_score;
-	guint disable_bookmark_editing_notifier_id;
 
 #ifdef ENABLE_ZEROCONF
 	/* Local sites */
@@ -630,14 +627,6 @@ topics_removed_cb (EphyNode *node,
 	}
 }
 
-static void
-update_bookmark_editing (EphyBookmarks *eb)
-{
-	g_object_set (G_OBJECT (eb->priv->db),
-		      "immutable", eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING),
-		      NULL);
-}
-
 static void
 fix_hierarchy_topic (EphyBookmarks *eb,
 		     EphyNode *topic)
@@ -693,15 +682,6 @@ fix_hierarchy (EphyBookmarks *eb)
 	}
 }
 
-static void
-disable_bookmark_editing_notifier (GConfClient *client,
-				   guint cnxn_id,
-				   GConfEntry *entry,
-				   EphyBookmarks *eb)
-{
-	update_bookmark_editing (eb);
-}
-
 static void
 backup_file (const char *original_filename, const char *extension)
 {
@@ -1340,10 +1320,10 @@ ephy_bookmarks_init (EphyBookmarks *eb)
 	
 	fix_hierarchy (eb);
 
-	eb->priv->disable_bookmark_editing_notifier_id = eel_gconf_notification_add
-		(CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING,
-		 (GConfClientNotifyFunc)disable_bookmark_editing_notifier, eb);
-	update_bookmark_editing (eb);
+	g_settings_bind (EPHY_SETTINGS_LOCKDOWN,
+			 EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING,
+			 eb->priv->db, "immutable",
+			 G_SETTINGS_BIND_GET);
 
 	ephy_setup_history_notifiers (eb);
 	ephy_bookmarks_update_favorites (eb);
@@ -1355,8 +1335,6 @@ ephy_bookmarks_finalize (GObject *object)
 	EphyBookmarks *eb = EPHY_BOOKMARKS (object);
 	EphyBookmarksPrivate *priv = eb->priv;
 
-	eel_gconf_notification_remove (priv->disable_bookmark_editing_notifier_id);
-
 	if (priv->save_timeout_id != 0)
 	{
 		g_source_remove (priv->save_timeout_id);
@@ -1372,6 +1350,7 @@ ephy_bookmarks_finalize (GObject *object)
 	ephy_node_unref (priv->keywords);
 	ephy_node_unref (priv->favorites);
 	ephy_node_unref (priv->notcategorized);
+	ephy_node_unref (priv->smartbookmarks);
 
 	g_object_unref (priv->db);
 
@@ -1938,30 +1917,55 @@ ephy_bookmarks_unset_keyword (EphyBookmarks *eb,
 	g_signal_emit (G_OBJECT (eb), ephy_bookmarks_signals[TREE_CHANGED], 0);
 }
 
+/**
+ * ephy_bookmarks_get_smart_bookmarks:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_smart_bookmarks (EphyBookmarks *eb)
 {
 	return eb->priv->smartbookmarks;
 }
 
+/**
+ * ephy_bookmarks_get_keywords:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_keywords (EphyBookmarks *eb)
 {
 	return eb->priv->keywords;
 }
 
+/**
+ * ephy_bookmarks_get_bookmarks:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_bookmarks (EphyBookmarks *eb)
 {
 	return eb->priv->bookmarks;
 }
 
+/**
+ * ephy_bookmarks_get_favorites:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_favorites (EphyBookmarks *eb)
 {
 	return eb->priv->favorites;
 }
 
+/**
+ * ephy_bookmarks_get_local:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_local (EphyBookmarks *eb)
 {
@@ -1972,12 +1976,22 @@ ephy_bookmarks_get_local (EphyBookmarks *eb)
 #endif
 }
 
+/**
+ * ephy_bookmarks_get_not_categorized:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_not_categorized (EphyBookmarks *eb)
 {
 	return eb->priv->notcategorized;
 }
 
+/**
+ * ephy_bookmarks_get_from_id:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_from_id (EphyBookmarks *eb, long id)
 {
